---
slug: /pyseekdb-sdk-get-started
---

# Get started

## pyseekdb

pyseekdb is a Python client provided by OceanBase. It allows you to connect to seekdb in embedded mode or remote mode, and supports connecting to seekdb in server mode or OceanBase Database.

:::tip
OceanBase Database is a fully self-developed, enterprise-level, native distributed database provided by OceanBase. It achieves financial-grade high availability on ordinary hardware and sets a new standard for automatic, lossless disaster recovery across cities with the "five IDCs across three regions" architecture. It also sets a new benchmark in the TPC-C standard test, with a single cluster scale exceeding 1,500 nodes. It is cloud-native, highly consistent, and highly compatible with Oracle and MySQL.
:::

pyseekdb is supported on Linux, macOS, and Windows. The supported database connection modes vary by operating system. For more information, see the table below.

| System | Embedded seekdb | Server mode seekdb | Server mode OceanBase Database |
|----|---|---|---|
| Linux | Supported | Supported | Supported |
| macOS | Not supported | Supported | Supported |
| Windows | Not supported | Supported | Supported |

For Linux system, when you install this client, it will also install seekdb in embedded mode, allowing you to directly connect to it to perform operations such as creating a database. Alternatively, you can choose to connect to a deployed seekdb or OceanBase Database in client/server mode.

## Install pyseekdb

### Prerequisites

Make sure that your environment meets the following requirements:

* Operating system: Linux (glibc >= 2.28), macOS or Windows
* Python version: Python 3.11 and later
* System architecture: x86_64 or aarch64

### Procedure

Use pip to install pyseekdb. It will automatically detect the default Python version and platform.

```shell
pip install pyseekdb
```

If your pip version is outdated, upgrade it before installation.

```bash
pip install --upgrade pip
```

## What to do next

* After installing pyseekdb, you can connect to seekdb to perform operations. For information about the API interfaces supported by pyseekdb, see [API Reference](../50.apis/10.api-overview.md).

* You can also refer to the SDK samples provided to quickly experience pyseekdb.

  * [Simple sample](50.sdk-samples/10.pyseekdb-simple-sample.md)

  * [Complete sample](50.sdk-samples/50.pyseekdb-complete-sample.md)

  * [Hybrid search sample](50.sdk-samples/100.pyseekdb-hybrid-search-sample.md)

